# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]
## [12.0.1.2.1] - 2025-01-07
### Added
- [#9](https://gitlab.com/somitcoop/erp-research/odoo-knowledge/-/merge_requests/9) Add api_reference field to pages

## [12.0.1.2.0] - 2024-09-23
### Added
- [#6](https://gitlab.com/somitcoop/erp-research/odoo-knowledge/-/merge_requests/6) added a new endpoint for retrieving the pages with a specific tag (by tag name)
## [12.0.1.1.0] - 2024-07-09
### Added
- [#4](https://gitlab.com/somitcoop/erp-research/odoo-knowledge/-/merge_requests/4) added a new endpoint for retrieving the pages based on highlighted
## [12.0.1.0.0] - 2024-07-01
### Added
- [#1](https://gitlab.com/somitcoop/erp-research/odoo-knowledge/-/merge_requests/1) Add knowledge_pages_api module
